==> Chicken-Ipsum-1.000001.tar.gz: Chicken-Ipsum-1.000001/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.1] - 2023-12-07

### Fixed
- Fix `List::Util` version issue in test (#1)
- Add necessary runtime version check for `List::Util`

## [1.0.0] - 2023-08-25

### Added
- Frantic mode (`frantic => NUMBER`).

### Changed
- Replace `Changes` with `CHANGELOG.md`
- Require Perl 5.12 or later

### Fixed
- Fix sentences having too many words
- Fix changelog links

## [0.03] - 2023-08-15

### Added
- Start changelog
- Add test for script

### Changed
- ~~Change over to non-semver versioning~~ (reverted in 1.0.0)
- Split POD to separate file
- Improve help message
- Minor other documentation changes

### Fixed
- Fix CPAN distribution tarball; it was missing some files (including this one)

## [0.0.2] - 2023-08-11

### Changed
- Minor other text changes

### Fixed
- Fix help message

### Removed
- Remove `_get_word` private method

## [0.0.1] - 2023-08-10
Initial published version

[Unreleased]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v1.0.1...HEAD
[1.0.1]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v1.0.0...v1.0.1
[1.0.0]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.03...v1.0.0
[0.03]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.0.2...v0.03
[0.0.2]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.0.1...v0.0.2
[0.0.1]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/releases/tag/v0.0.1

==> Chicken-Ipsum-1.000002.tar.gz: Chicken-Ipsum-1.000002/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.2] - 2024-03-31

### Fixed
- Fix test under Perl v5.39.8

## [1.0.1] - 2023-12-07

### Fixed
- Fix `List::Util` version issue in test (#1)
- Add necessary runtime version check for `List::Util`

## [1.0.0] - 2023-08-25

### Added
- Frantic mode (`frantic => NUMBER`).

### Changed
- Replace `Changes` with `CHANGELOG.md`
- Require Perl 5.12 or later

### Fixed
- Fix sentences having too many words
- Fix changelog links

## [0.03] - 2023-08-15

### Added
- Start changelog
- Add test for script

### Changed
- ~~Change over to non-semver versioning~~ (reverted in 1.0.0)
- Split POD to separate file
- Improve help message
- Minor other documentation changes

### Fixed
- Fix CPAN distribution tarball; it was missing some files (including this one)

## [0.0.2] - 2023-08-11

### Changed
- Minor other text changes

### Fixed
- Fix help message

### Removed
- Remove `_get_word` private method

## [0.0.1] - 2023-08-10
Initial published version

[Unreleased]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v1.0.2...HEAD
[1.0.2]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v1.0.1...v1.0.2
[1.0.1]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v1.0.0...v1.0.1
[1.0.0]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.03...v1.0.0
[0.03]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.0.2...v0.03
[0.0.2]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/compare/v0.0.1...v0.0.2
[0.0.1]: https://codeberg.org/h3xx/perl-Chicken-Ipsum/releases/tag/v0.0.1
